@@ -563,7 +563,11 @@ on_build_mesg_format (IAnjutaMessageView *view, const gchar *one_line,
 	if ((sscanf (one_line, _("make[%d]: Entering directory '%s'"), &dummy_int, dir) == 2) ||
 		(sscanf (one_line, _("make: Entering directory '%s'"), dir) == 1) ||
 		(sscanf (one_line, _("make[%d]: Entering directory `%s'"), &dummy_int, dir) == 2) ||
-		(sscanf (one_line, _("make: Entering directory `%s'"), dir) == 1))
+		(sscanf (one_line, _("make: Entering directory `%s'"), dir) == 1) ||
+		(sscanf (one_line, "make[%d]: Entering directory '%s'", &dummy_int, dir) == 2) ||
+		(sscanf (one_line, "make: Entering directory '%s'", dir) == 1) ||
+		(sscanf (one_line, "make[%d]: Entering directory `%s'", &dummy_int, dir) == 2) ||
+		(sscanf (one_line, "make: Entering directory `%s'", dir) == 1))
 	{
 		gchar* summary;
 		/* FIXME: Hack to remove the last ' */
@@ -585,7 +589,12 @@ on_build_mesg_format (IAnjutaMessageView *view, const gchar *one_line,
 	if ((sscanf (one_line, _("make[%d]: Leaving directory '%s'"), &dummy_int, dir) == 2) ||
 		(sscanf (one_line, _("make: Leaving directory '%s'"), dir) == 1) ||
 		(sscanf (one_line, _("make[%d]: Leaving directory `%s'"), &dummy_int, dir) == 2) ||
-		(sscanf (one_line, _("make: Leaving directory `%s'"), dir) == 1))
+		(sscanf (one_line, _("make: Leaving directory `%s'"), dir) == 1) ||
+		(sscanf (one_line, "make[%d]: Leaving directory '%s'", &dummy_int, dir) == 2) ||
+		(sscanf (one_line, "make: Leaving directory '%s'", dir) == 1) ||
+		(sscanf (one_line, "make[%d]: Leaving directory `%s'", &dummy_int, dir) == 2) ||
+		(sscanf (one_line, "make: Leaving directory `%s'", dir) == 1))
+
 	{
 		gchar* summary;
 		/* FIXME: Hack to remove the last ' */
@@ -731,7 +740,7 @@ on_build_mesg_parse (IAnjutaMessageView *view, const gchar *line,
 		g_free(filename);
 		if (uri)
 		{
-			ianjuta_document_manager_goto_file_line_mark(docman, uri, lineno, TRUE, NULL);
+			ianjuta_document_manager_goto_uri_line_mark(docman, uri, lineno, TRUE, NULL);
 			g_free(uri);
 		}
 	}
@@ -812,6 +821,8 @@ build_get_context (BasicAutotoolsPlugin *plugin, const gchar *dir,
 	build_regex_init();
 
 	subdir = g_path_get_basename (dir);
+	/* Translators: the first number is the number of the build attemp,
+	   the string is the directory where the build takes place */
 	snprintf (mname, 128, _("Build %d: %s"), ++message_pane_count, subdir);
 	g_free (subdir);
 	
@@ -1053,6 +1064,7 @@ build_configure_project (GtkAction *action, BasicAutotoolsPlugin *plugin)
 	gchar *input = NULL;
 	
 	parent = GTK_WINDOW (ANJUTA_PLUGIN(plugin)->shell);
+	/* Configure = ./configure script */
 	response = anjuta_util_dialog_input (parent, _("Configure Parameters:"),
 										 plugin->configure_args, &input);
 	if (response)
