@@ -746,6 +746,7 @@ breakpoints_dbase_add_in_debugger (BreakpointsDBase *bd, BreakpointItem *bi)
 		breakpoint_item_ref (bi);
 		ok = dma_queue_add_breakpoint_at_line (
 					bd->debugger,
+					&(bi->bp.id),											   
 					bi->bp.file,
 					bi->bp.line,
 					on_breakpoint_callback,
@@ -756,6 +757,7 @@ breakpoints_dbase_add_in_debugger (BreakpointsDBase *bd, BreakpointItem *bi)
 		breakpoint_item_ref (bi);
 		ok = dma_queue_add_breakpoint_at_function (
 					bd->debugger,
+					&(bi->bp.id),											   
 					bi->bp.file == NULL ? "" : bi->bp.file,
 					bi->bp.function,
 					on_breakpoint_callback,
@@ -767,6 +769,7 @@ breakpoints_dbase_add_in_debugger (BreakpointsDBase *bd, BreakpointItem *bi)
 		breakpoint_item_ref (bi);
 		ok = dma_queue_add_breakpoint_at_address (
 					bd->debugger,
+					&(bi->bp.id),											   
 					bi->bp.address,
 					on_breakpoint_callback,
 					bi);
@@ -1418,15 +1421,18 @@ breakpoints_dbase_edit_breakpoint (BreakpointsDBase *bd, BreakpointItem *bi)
 	pass_entry = glade_xml_get_widget (gxml, "breakpoint_pass_entry");
 	pass_label = glade_xml_get_widget (gxml, "breakpoint_pass_label");
 
-	if (!dma_debugger_queue_is_supported(bd->debugger, HAS_IGNORE_BREAKPOINT))
+	if (bd->debugger != NULL)
 	{
-		gtk_widget_hide (pass_entry);
-		gtk_widget_hide (pass_label);
-	}
-	if (!dma_debugger_queue_is_supported(bd->debugger, HAS_CONDITION_BREAKPOINT))
-	{
-		gtk_widget_hide (condition_entry);
-		gtk_widget_hide (condition_label);
+		if (!dma_debugger_queue_is_supported(bd->debugger, HAS_IGNORE_BREAKPOINT))
+		{	
+			gtk_widget_hide (pass_entry);
+			gtk_widget_hide (pass_label);
+		}
+		if (!dma_debugger_queue_is_supported(bd->debugger, HAS_CONDITION_BREAKPOINT))
+		{
+			gtk_widget_hide (condition_entry);
+			gtk_widget_hide (condition_label);
+		}
 	}
 	
 	if (bi == NULL)
@@ -1445,7 +1451,7 @@ breakpoints_dbase_edit_breakpoint (BreakpointsDBase *bd, BreakpointItem *bi)
 			uri = ianjuta_file_get_uri (IANJUTA_FILE (te), NULL);
 			line = ianjuta_editor_get_lineno (te, NULL);
 		}
-		//NULL uri ia ok here
+		//NULL uri is ok here
 		bi = breakpoint_item_new_from_uri (bd, uri, line, TRUE);
 		new_break = TRUE;
 	}
@@ -1595,7 +1601,7 @@ on_toggle_breakpoint_activate (GtkAction * action, BreakpointsDBase *bd)
 	uri = ianjuta_file_get_uri (IANJUTA_FILE (te), NULL);
 	if (uri == NULL) return;     /* File not saved yet, it's not possible to put a breakpoint in it */
 	line = ianjuta_editor_get_lineno (te, NULL);
-	
+
 	/* Find corresponding breakpoint
 	 * Try to find right mark (it could have moved) first */
 	bi = breakpoints_dbase_find_breakpoint_from_mark (bd, te, line);
@@ -1785,9 +1791,9 @@ static GtkActionEntry actions_debugger_breakpoints[] = {
 	{
 		"ActionDmaClearAllBreakpoints",           /* Action name */
 		ANJUTA_STOCK_BREAKPOINT_CLEAR,            /* Stock icon, if any */
-		N_("C_lear All Breakpoints"),             /* Display label */
+		N_("R_emove All Breakpoints"),             /* Display label */
 		NULL,                                     /* short-cut */
-		N_("Delete all breakpoints"),             /* Tooltip */
+		N_("Remove all breakpoints"),             /* Tooltip */
 		G_CALLBACK (on_clear_all_breakpoints_activate)/* action callback */
 	},
 };		
