@@ -26,6 +26,8 @@
 
 #include "sexy-icon-entry.h"
 
+#include <libgnome/gnome-i18n.h>
+
 #include <gdk/gdkkeysyms.h>
 
 #include <stdlib.h>
@@ -378,7 +380,7 @@ dma_data_view_populate_popup (GtkTextView *widget,
 	gtk_widget_show (menu_item);
 
 	/* create goto menu_item. */
-	menu_item = gtk_menu_item_new_with_mnemonic ("_Goto address");
+	menu_item = gtk_menu_item_new_with_mnemonic (_("_Goto address"));
 	g_signal_connect (G_OBJECT (menu_item), "activate",
 			  G_CALLBACK (dma_data_view_goto_activate), view);
 	gtk_menu_shell_prepend (GTK_MENU_SHELL (menu), menu_item);
