@@ -15,12 +15,15 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */
 
 #ifndef _SHAREDLIBS_H_
 #define _SHAREDLIBS_H_
 
+#include "plugin.h"
+#include "queue.h"
+
 #include <libanjuta/anjuta-plugin.h>
 #include <libanjuta/interfaces/ianjuta-debugger.h>
 
@@ -41,13 +44,13 @@ struct _SharedlibsGui
 struct _Sharedlibs
 {
 	SharedlibsGui  widgets;
-	IAnjutaDebugger *debugger;
+	DmaDebuggerQueue *debugger;
 	gboolean is_showing;
 	gint win_pos_x, win_pos_y, win_width, win_height;
 };
 
 Sharedlibs*
-sharedlibs_new (IAnjutaDebugger *debugger);
+sharedlibs_new (DebugManagerPlugin *plugin);
 
 void
 sharedlibs_clear (Sharedlibs *ew);
