@@ -233,16 +233,24 @@ static GtkActionEntry actions_select[] = {
 };
 
 static GtkActionEntry actions_comment[] = {
-  { "ActionMenuEditComment", NULL, N_("Co_mment"), NULL, NULL, NULL}, /* menu title */
+  { "ActionMenuEditComment", NULL, N_("Co_mment"), NULL, NULL, NULL},
+	/* Block comment: Uses line-comment (comment that affects only single line
+	such as '//' or '#') and comments a block of lines. */
   { "ActionEditCommentBlock", NULL, N_("_Block Comment/Uncomment"), NULL,
 	N_("Block comment the selected text"),
     G_CALLBACK (on_comment_block)},
+	/* Box comment: Uses stream-comment to comment a block of lines, usually with
+	some decorations, to give an appearance of box. */
   { "ActionEditCommentBox", NULL, N_("Bo_x Comment/Uncomment"), NULL,
 	N_("Box comment the selected text"),
     G_CALLBACK (on_comment_box)},
+	/* Stream comment: Uses 'stream comment' (comment that affects a stream of
+	characters -- has start and end comment code) and comments any code from
+	arbitrary start position to arbitrary end position (can be in middle of
+	lines). */
   { "ActionEditCommentStream", NULL, N_("_Stream Comment/Uncomment"), NULL,
 	N_("Stream comment the selected text"),
-    G_CALLBACK (on_comment_block)},
+    G_CALLBACK (on_comment_stream)},
 };
 
 static GtkActionEntry actions_navigation[] = {
@@ -1140,14 +1148,22 @@ on_document_changed (AnjutaDocman *docman, IAnjutaDocument *doc,
 					 AnjutaPlugin *plugin)
 {
 	update_document_ui (plugin, doc);
-
-	GValue value = {0, };
-	g_value_init (&value, G_TYPE_OBJECT);
-	g_value_set_object (&value, doc);
-	anjuta_shell_add_value (plugin->shell,
-							"document_manager_current_editor",
-							&value, NULL);
-	g_value_unset(&value);
+	
+	if (doc)
+	{
+		GValue value = {0, };
+		g_value_init (&value, G_TYPE_OBJECT);
+		g_value_set_object (&value, doc);
+		anjuta_shell_add_value (plugin->shell,
+								"document_manager_current_editor",
+								&value, NULL);
+		g_value_unset(&value);
+	}
+	else
+	{
+		anjuta_shell_remove_value (plugin->shell, "document_manager_current_editor",
+								   NULL);
+	}
 
 	if (doc && IANJUTA_IS_EDITOR (doc))
 	{
@@ -1447,7 +1463,9 @@ docman_plugin_set_tab_pos (DocmanPlugin *ep)
 		pos = GTK_POS_TOP;
 		if (tab_pos)
 		{
-			if (strcasecmp (tab_pos, "left") == 0)
+			if (strcasecmp (tab_pos, "top") == 0)
+				pos = GTK_POS_TOP;
+			else if (strcasecmp (tab_pos, "left") == 0)
 				pos = GTK_POS_LEFT;
 			else if (strcasecmp (tab_pos, "right") == 0)
 				pos = GTK_POS_RIGHT;
@@ -1735,6 +1753,7 @@ activate_plugin (AnjutaPlugin *plugin)
 								 value_removed_project_root_uri, NULL);
 	dplugin->project_name = NULL;
 	
+	prefs_init(ANJUTA_PLUGIN_DOCMAN (plugin));		
 	initialized = TRUE;
 	
 	return TRUE;
@@ -1829,12 +1848,12 @@ docman_plugin_class_init (GObjectClass *klass)
 
 /* Implement IAnjutaDocumentManager interfaces */
 static gchar*
-ianjuta_docman_get_full_filename (IAnjutaDocumentManager *plugin,
-		const gchar *file, GError **e)
+ianjuta_docman_get_uri (IAnjutaDocumentManager *plugin,
+		const gchar *filename, GError **e)
 {
 	AnjutaDocman *docman;
 	docman = ANJUTA_DOCMAN ((ANJUTA_PLUGIN_DOCMAN (plugin)->docman));
-	return anjuta_docman_get_full_filename (docman, file);
+	return anjuta_docman_get_uri (docman, filename);
 }
 
 static IAnjutaDocument*
@@ -1872,21 +1891,21 @@ ianjuta_docman_get_doc_widgets (IAnjutaDocumentManager *plugin, GError **e)
 }
 
 static IAnjutaEditor*
-ianjuta_docman_goto_file_line (IAnjutaDocumentManager *plugin,
+ianjuta_docman_goto_uri_line (IAnjutaDocumentManager *plugin,
 							   const gchar *uri, gint linenum, GError **e)
 {
 	AnjutaDocman *docman;
 	docman = ANJUTA_DOCMAN ((ANJUTA_PLUGIN_DOCMAN (plugin)->docman));
-	return anjuta_docman_goto_file_line (docman, uri, linenum);
+	return anjuta_docman_goto_uri_line (docman, uri, linenum);
 }
 
 static IAnjutaEditor*
-ianjuta_docman_goto_file_line_mark (IAnjutaDocumentManager *plugin,
+ianjuta_docman_goto_uri_line_mark (IAnjutaDocumentManager *plugin,
 		const gchar *uri, gint linenum, gboolean mark, GError **e)
 {
 	AnjutaDocman *docman;
 	docman = ANJUTA_DOCMAN ((ANJUTA_PLUGIN_DOCMAN (plugin)->docman));
-	return anjuta_docman_goto_file_line_mark (docman, uri, linenum, mark);
+	return anjuta_docman_goto_uri_line_mark (docman, uri, linenum, mark);
 }
 
 /**
@@ -1957,12 +1976,12 @@ ianjuta_document_manager_iface_init (IAnjutaDocumentManagerIface *iface)
 {
 	iface->add_buffer = ianjuta_docman_add_buffer;
 	iface->add_document = ianjuta_docman_add_document;
-	iface->find_document_with_path = ianjuta_docman_get_document_for_uri;
+	iface->find_document_with_uri = ianjuta_docman_get_document_for_uri;
 	iface->get_current_document = ianjuta_docman_get_current_document;
 	iface->get_doc_widgets = ianjuta_docman_get_doc_widgets;
-	iface->get_full_filename = ianjuta_docman_get_full_filename;
-	iface->goto_file_line = ianjuta_docman_goto_file_line;
-	iface->goto_file_line_mark = ianjuta_docman_goto_file_line_mark;
+	iface->get_uri = ianjuta_docman_get_uri;
+	iface->goto_uri_line = ianjuta_docman_goto_uri_line;
+	iface->goto_uri_line_mark = ianjuta_docman_goto_uri_line_mark;
 	iface->remove_document = ianjuta_docman_remove_document;
 	iface->set_current_document = ianjuta_docman_set_current_document;
 }
@@ -1974,7 +1993,7 @@ ifile_open (IAnjutaFile* plugin, const gchar* uri, GError** e)
 	AnjutaDocman *docman;
 	
 	docman = ANJUTA_DOCMAN ((ANJUTA_PLUGIN_DOCMAN (plugin)->docman));
-	anjuta_docman_goto_file_line_mark (docman, uri, -1, FALSE);
+	anjuta_docman_goto_uri_line_mark (docman, uri, -1, FALSE);
 }
 
 static gchar*
@@ -2081,8 +2100,7 @@ isavable_iface_init (IAnjutaFileSavableIface *iface)
 static void
 ipreferences_merge(IAnjutaPreferences* ipref, AnjutaPreferences* prefs, GError** e)
 {
-	GladeXML* gxml;		
-	AnjutaPlugin *plugin = ANJUTA_PLUGIN (ipref);
+	GladeXML* gxml;
 	
 	/* Add preferences */
 	gxml = glade_xml_new (PREFS_GLADE, "preferences_dialog", NULL);
@@ -2091,7 +2109,6 @@ ipreferences_merge(IAnjutaPreferences* ipref, AnjutaPreferences* prefs, GError**
 									gxml, "Documents", _("Documents"),  ICON_FILE);
 	anjuta_encodings_init (prefs, gxml);
 				
-	prefs_init(ANJUTA_PLUGIN_DOCMAN (plugin));		
 	g_object_unref (G_OBJECT (gxml));
 }
 
