@@ -29,6 +29,7 @@
 
 #include "text_editor.h"
 #include "text_editor_cbs.h"
+#include "text-editor-iterable.h"
 
 #define GTK
 #undef PLAT_GTK
@@ -172,11 +173,14 @@ on_text_editor_scintilla_notify (GtkWidget * sci, gint wParam, gpointer lParam,
 		return;
 		
 	case SCN_CHARADDED:
-		te->current_line = text_editor_get_current_lineno (te);
-		position = text_editor_get_current_position (te) - 1;
-		g_signal_emit_by_name(G_OBJECT (te), "char_added", position,
-							  (gchar)nt->ch);
-		
+		{
+			position = text_editor_get_current_position (te) - 1;
+			TextEditorCell *position_iter = text_editor_cell_new (te, position);
+			te->current_line = text_editor_get_current_lineno (te);
+			g_signal_emit_by_name(G_OBJECT (te), "char-added", position_iter,
+								  (gchar)nt->ch);
+			g_object_unref (position_iter);
+		}
 		return;
 	case SCN_AUTOCSELECTION:
 	case SCN_USERLISTSELECTION:
@@ -190,10 +194,13 @@ on_text_editor_scintilla_notify (GtkWidget * sci, gint wParam, gpointer lParam,
 	case SCN_MODIFIED:
 		if (nt->modificationType & (SC_MOD_INSERTTEXT | SC_MOD_DELETETEXT))
 		{
+			TextEditorCell *position_iter =
+					text_editor_cell_new (te, nt->position);
 			gboolean added = nt->modificationType & SC_MOD_INSERTTEXT;
-			g_signal_emit_by_name (G_OBJECT (te), "changed", nt->position,
+			g_signal_emit_by_name (G_OBJECT (te), "changed", position_iter,
 								   added, nt->length, nt->linesAdded,
 								   nt->text);
+			g_object_unref (position_iter);
 		}
 		return;
 	case SCN_MARGINCLICK:
@@ -221,7 +228,24 @@ on_text_editor_scintilla_notify (GtkWidget * sci, gint wParam, gpointer lParam,
 			}
 	}
 	return;
-	
+	case SCN_DWELLSTART:
+    {
+      TextEditorCell* cell = nt->position < 0 ? NULL : text_editor_cell_new (te, nt->position); 
+      g_signal_emit_by_name (te, "hover-over", cell);
+      if (cell) g_object_unref (cell);
+      return;
+    }
+		
+	case SCN_DWELLEND:
+    {
+      TextEditorCell* cell = nt->position < 0 ? NULL : text_editor_cell_new (te, nt->position); 
+      
+      text_editor_hide_hover_tip (te);
+      g_signal_emit_by_name (te, "hover-leave", cell);
+      if (cell) g_object_unref (cell);
+      return;
+    }
+
 /*	case SCEN_SETFOCUS:
 	case SCEN_KILLFOCUS:
 	case SCN_STYLENEEDED:
