@@ -1161,7 +1161,7 @@ on_editor_char_inserted_cpp (IAnjutaEditor *editor,
 				ch = ianjuta_editor_cell_get_char (IANJUTA_EDITOR_CELL (iter),
 												   0, NULL);
 				
-				/* DEBUG_PRINT ("Looking at char '%c'", ch); */
+				//DEBUG_PRINT ("Looking at char '%c'", ch);
 				
 				/* Break on begining of line (== end of previous line) */
 				if (iter_is_newline (iter, ch))
@@ -1483,7 +1483,7 @@ cpp_java_plugin_activate_plugin (AnjutaPlugin *plugin)
 	ui = anjuta_shell_get_ui (plugin->shell, NULL);
 	lang_plugin->action_group = 
 		anjuta_ui_add_action_group_entries (ui, "ActionGroupCppJavaAssist",
-											_("Cpp/Java Assistance"),
+											_("C++/Java Assistance"),
 											actions,
 											G_N_ELEMENTS (actions),
 											GETTEXT_PACKAGE, TRUE,
