@@ -27,7 +27,7 @@
  * list of people on the anjuta Team.  
  * See the ChangeLog files for a list of changes.
  *
- * $Id: anjuta-view.c 3514 2008-01-24 11:21:05Z jhs $ 
+ * $Id: anjuta-view.c 3559 2008-01-31 22:49:14Z jhs $ 
  */
 
 #ifdef HAVE_CONFIG_H
@@ -764,33 +764,35 @@ anjuta_view_key_press_event		(GtkWidget *widget, GdkEventKey       *event)
 	SourceviewCell* cell;
 	
 	buffer  = gtk_text_view_get_buffer (GTK_TEXT_VIEW (view));
-
+	
 	assist_win = view->priv->sv->priv->assist_win;
 	assist_tip = view->priv->sv->priv->assist_tip;
 	if (assist_win)
 	{
-	  if (assist_window_filter_keypress(assist_win, event->keyval))
-	  {
+		if (assist_window_filter_keypress(assist_win, event->keyval))
+		{
 			DEBUG_PRINT("key filtered: %d", event->keyval);
 			return TRUE;
-	  }
+		}
 	}
 	
 	switch (event->keyval)
-	 {
+	{
 		case GDK_Shift_L:
 		case GDK_Shift_R:
 		{
 			return TRUE;
 		}
 		default:
-		 {
+		{
 			gboolean retval = (* GTK_WIDGET_CLASS (anjuta_view_parent_class)->key_press_event)(widget, event);
 			gtk_text_buffer_get_iter_at_mark(buffer, &iter, 
-									 gtk_text_buffer_get_insert(buffer));
+											 gtk_text_buffer_get_insert(buffer));
+			/* Iter is at the position after the newly added character... */
+				gtk_text_iter_backward_char (&iter);
 			cell = sourceview_cell_new (&iter, GTK_TEXT_VIEW (view));
 			/* Handle char_added signal here */
-			if (event->keyval == GDK_Return)
+				if (event->keyval == GDK_Return)
 			{
 				g_signal_emit_by_name (G_OBJECT(view), "char_added",
 									   cell, '\n');
@@ -806,26 +808,25 @@ anjuta_view_key_press_event		(GtkWidget *widget, GdkEventKey       *event)
 									  cell, '\0');
 			}
 			else if (event->keyval == GDK_Escape || 
-							 event->keyval == GDK_Up ||
-							 event->keyval == GDK_Down)
+					 event->keyval == GDK_Up ||
+					 event->keyval == GDK_Down)
 			{
 				if (assist_tip)
-        {
+				{
 					gtk_widget_destroy (GTK_WIDGET(assist_tip));
 					g_object_unref (cell);
-          return retval;
-        }
+					return retval;
+				}
 			}
 			else if (event->keyval == GDK_Left || event->keyval == GDK_Right ||
-							 event->keyval == GDK_Up || event->keyval == GDK_Down ||
-							 event->keyval == GDK_Page_Up || event->keyval == GDK_Page_Down ||
-							 event->keyval == GDK_Begin || event->keyval == GDK_End)
+					 event->keyval == GDK_Up || event->keyval == GDK_Down ||
+					 event->keyval == GDK_Page_Up || event->keyval == GDK_Page_Down ||
+					 event->keyval == GDK_Begin || event->keyval == GDK_End)
 			{
 				/* Ignore those for char_added */
 				g_object_unref (cell);
 				return retval;
 			}
-							 
 			else
 			{
 				gchar* unistring = g_new0(gchar, 6);
