@@ -449,8 +449,6 @@ sourceview_finalize(GObject *object)
 	Sourceview *cobj;
 	cobj = ANJUTA_SOURCEVIEW(object);
 	
-	DEBUG_PRINT("=========== finalise =============");
-	
 	sourceview_remove_monitor(cobj);
 	sourceview_prefs_destroy(cobj);
 	
@@ -458,6 +456,7 @@ sourceview_finalize(GObject *object)
 	
 	g_slice_free(SourceviewPrivate, cobj->priv);
 	G_OBJECT_CLASS(parent_class)->finalize(object);
+	DEBUG_PRINT("=========== finalise =============");
 }
 
 /* Sync with IANJUTA_MARKABLE_MARKER  */
@@ -1469,7 +1468,7 @@ static gboolean mark_real (gpointer data)
 	name = CREATE_MARK_NAME (marker_count);
 	
 	
-	source_mark = gtk_source_buffer_create_mark(GTK_SOURCE_BUFFER(sv->priv->document), 
+	source_mark = gtk_source_buffer_create_source_mark(GTK_SOURCE_BUFFER(sv->priv->document), 
 												name, category, &iter);
 	
 	g_source_remove (svmark->source);
@@ -1514,7 +1513,7 @@ imark_unmark(IAnjutaMarkable* mark, gint location, IAnjutaMarkableMarker marker,
 	gtk_text_buffer_get_iter_at_line (GTK_TEXT_BUFFER (buffer), &begin, LOCATION_TO_LINE (location));
 	gtk_text_buffer_get_iter_at_line (GTK_TEXT_BUFFER (buffer), &end, LOCATION_TO_LINE (location));
 	
-	gtk_source_buffer_remove_marks (buffer, &begin, &end, marker_types[marker]);
+	gtk_source_buffer_remove_source_marks (buffer, &begin, &end, marker_types[marker]);
 	
 }
 
@@ -1527,7 +1526,7 @@ imark_is_marker_set(IAnjutaMarkable* mark, gint location,
 	GSList* markers;
 	gboolean retval;
 	
-	markers = gtk_source_buffer_get_marks_at_line (buffer, 
+	markers = gtk_source_buffer_get_source_marks_at_line (buffer, 
 												   LOCATION_TO_LINE (location), 
 												   marker_types[marker]);	
 	
@@ -1573,7 +1572,7 @@ imark_delete_all_markers(IAnjutaMarkable* imark, IAnjutaMarkableMarker marker,
 	gtk_text_buffer_get_iter_at_offset (GTK_TEXT_BUFFER (buffer), &begin, 0);
 	gtk_text_buffer_get_iter_at_offset (GTK_TEXT_BUFFER (buffer), &end, -1);
 	
-	gtk_source_buffer_remove_marks (buffer, &begin, &end, marker_types[marker]);
+	gtk_source_buffer_remove_source_marks (buffer, &begin, &end, marker_types[marker]);
 }
 
 static void
@@ -1652,7 +1651,7 @@ ibookmark_toggle(IAnjutaBookmark* bmark, gint location, gboolean ensure_visible,
 	
 	GSList* markers;
 	
-	markers = gtk_source_buffer_get_marks_at_line (buffer, LOCATION_TO_LINE (location),
+	markers = gtk_source_buffer_get_source_marks_at_line (buffer, LOCATION_TO_LINE (location),
 												   marker_types[IANJUTA_MARKABLE_BOOKMARK]);
 	if (markers != NULL)
 	{
@@ -1662,7 +1661,7 @@ ibookmark_toggle(IAnjutaBookmark* bmark, gint location, gboolean ensure_visible,
 		gtk_text_buffer_get_iter_at_line (GTK_TEXT_BUFFER (buffer), &begin, LOCATION_TO_LINE (location));
 		gtk_text_buffer_get_iter_at_line (GTK_TEXT_BUFFER (buffer), &end, LOCATION_TO_LINE (location));
 		
-		gtk_source_buffer_remove_marks (buffer, &begin, &end, 
+		gtk_source_buffer_remove_source_marks (buffer, &begin, &end, 
 										marker_types[IANJUTA_MARKABLE_BOOKMARK]);
 	}
 	else
@@ -1673,7 +1672,7 @@ ibookmark_toggle(IAnjutaBookmark* bmark, gint location, gboolean ensure_visible,
 															 &line, LOCATION_TO_LINE (location));
 		
 		bookmark = 
-			gtk_source_buffer_create_mark (buffer, NULL,
+			gtk_source_buffer_create_source_mark (buffer, NULL,
 											 marker_types [IANJUTA_MARKABLE_BOOKMARK],
 											 &line);
 	}
@@ -1686,10 +1685,10 @@ goto_bookmark (Sourceview* sv, GtkTextIter* iter, gboolean backward)
 	gboolean found = FALSE;
 	
 	if (backward)
-		found = gtk_source_buffer_backward_iter_to_mark (buffer, iter, 
+		found = gtk_source_buffer_backward_iter_to_source_mark (buffer, iter, 
 														 marker_types[IANJUTA_MARKABLE_BOOKMARK]);
 	else
-		found = gtk_source_buffer_forward_iter_to_mark (buffer, iter, 
+		found = gtk_source_buffer_forward_iter_to_source_mark (buffer, iter, 
 														marker_types[IANJUTA_MARKABLE_BOOKMARK]);
 	if (found)
 	{
@@ -1763,7 +1762,7 @@ ibookmark_clear_all(IAnjutaBookmark* bmark, GError** e)
 	gtk_text_buffer_get_iter_at_offset (GTK_TEXT_BUFFER (buffer), &begin, 0);
 	gtk_text_buffer_get_iter_at_offset (GTK_TEXT_BUFFER (buffer), &end, -1);
 	
-	gtk_source_buffer_remove_marks (buffer, &begin, &end, marker_types[IANJUTA_MARKABLE_BOOKMARK]);
+	gtk_source_buffer_remove_source_marks (buffer, &begin, &end, marker_types[IANJUTA_MARKABLE_BOOKMARK]);
 }
 
 static void
@@ -1993,7 +1992,13 @@ iassist_show_tips (IAnjutaEditorAssist *iassist, GList* tips, IAnjutaIterable* i
 				   gint char_alignment, GError **err)
 {
 	Sourceview* sv = ANJUTA_SOURCEVIEW(iassist);
-	int tip_position = ianjuta_iterable_get_position (ipos, NULL) - char_alignment;
+	GtkTextBuffer* buffer = GTK_TEXT_BUFFER (sv->priv->document);
+	GtkTextIter iter;
+	gint tip_position;
+	gtk_text_buffer_get_iter_at_mark (buffer, &iter,
+									  gtk_text_buffer_get_insert (buffer));
+	
+	tip_position = gtk_text_iter_get_offset (&iter) - char_alignment;
 	
 	if (tips == NULL)
 		return;
