@@ -42,7 +42,7 @@
 
 /*---------------------------------------------------------------------------*/
 
-#define ICON_FILE "anjuta-tools-plugin.png"
+#define ICON_FILE "anjuta-tools-plugin-48.png"
 #define MAX_TOOL_PANES 4
 
 /* Widget and signal name found in glade file
@@ -67,7 +67,7 @@ typedef struct
 	gboolean created;
 	GString* buffer;
 	IAnjutaEditor* editor;
-	guint position;
+	IAnjutaIterable *position;
 } ATPOutputContext;
 
 /* Execute information
@@ -503,7 +503,7 @@ atp_output_context_print_result (ATPOutputContext *this, gint error)
 		{
 			if (error)
 			{
-				buffer = g_strdup_printf (_("Completed unsuccessful with %d\n"),
+				buffer = g_strdup_printf (_("Completed unsuccessful with status code %d\n"),
 										  error);
 				ok = atp_output_context_print (this, buffer);
 				g_free (buffer);
@@ -669,7 +669,8 @@ atp_output_context_construct (ATPOutputContext *this,
 	this->execution = execution;
 	this->view = NULL;
 	this->buffer = NULL;
-
+	this->position = NULL;
+	
 	return atp_output_context_initialize (this, execution, type);
 }
 
@@ -689,6 +690,10 @@ atp_output_context_destroy (ATPOutputContext *this)
 	{
 		g_string_free (this->buffer, TRUE);
 	}
+	if (this->position)
+	{
+		g_object_unref (this->position);
+	}
 }
 
 /* Execution context
@@ -984,7 +989,7 @@ atp_user_tool_execute (GtkMenuItem *item, ATPUserTool* this)
 			ed = get_current_editor(docman);
 			if (ed != NULL)
 			{
-				input = ianjuta_editor_get_text (ed, 0, -1, NULL);
+				input = ianjuta_editor_get_text_all (ed, NULL);
 			}
 			break;
 		case ATP_TIN_SELECTION:
@@ -1008,7 +1013,7 @@ atp_user_tool_execute (GtkMenuItem *item, ATPUserTool* this)
 			if ((val == NULL) || (!g_file_get_contents (val, &input, NULL, NULL)))
 			{
 				anjuta_util_dialog_error (atp_plugin_get_app_window (plugin),
-										  _("Unable to open input file %s, Command aborted"), val == NULL ? "(null)" : val);		
+										  _("Unable to open input file %s, command aborted"), val == NULL ? "(null)" : val);		
 				if (val != NULL) g_free (val);
 				if (dir != NULL) g_free (dir);
 				if (cmd != NULL) g_free (cmd);
