@@ -14,8 +14,8 @@
  * for more details.
  * 
  * You should have received a copy of the GNU General Public License along
- * with this program; if not, write to the Free Software Foundation, Inc., 59 
- * Temple Place, Suite 330, Boston, MA  02111-1307  USA 
+ * with this program; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA 
  */
 
 #ifndef _ANJUTA_APP_H_
@@ -28,6 +28,7 @@
 #include <libanjuta/anjuta-ui.h>
 #include <libanjuta/anjuta-preferences.h>
 #include <libanjuta/anjuta-plugin-manager.h>
+#include <libanjuta/anjuta-profile-manager.h>
 
 G_BEGIN_DECLS
 
@@ -57,6 +58,7 @@ struct _AnjutaApp
 	AnjutaUI *ui;
 	AnjutaPreferences *preferences;
 	AnjutaPluginManager *plugin_manager;
+	AnjutaProfileManager *profile_manager;
 };
 
 struct _AnjutaAppClass
@@ -70,6 +72,7 @@ GtkWidget* anjuta_app_new (void);
 void       anjuta_app_set_geometry (AnjutaApp *app, const gchar *geometry);
 gchar*     anjuta_app_get_geometry (AnjutaApp *app);
 void       anjuta_app_layout_reset (AnjutaApp *app);
+void	   anjuta_app_install_preferences (AnjutaApp *app);
 
 G_END_DECLS
 
